package cn.com.qmth.stmms.ms.admin.service;

import cn.com.qmth.stmms.ms.core.domain.MarkStage;
import cn.com.qmth.stmms.ms.core.domain.Work;
import cn.com.qmth.stmms.ms.core.domain.enums.TrialEnum;
import cn.com.qmth.stmms.ms.core.repository.*;
import cn.com.qmth.stmms.ms.core.vo.Subject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.concurrent.atomic.AtomicBoolean;

/**
 * @Description: 试评任务
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2019/11/4
 */
@Service
public class TrialService {

    @Autowired
    WorkRepo workRepo;

    @Autowired
    MarkSubjectRepo markSubjectRepo;

    @Autowired
    StudentRepo studentRepo;

    @Autowired
    MarkTaskRepo markTaskRepo;

    @Autowired
    PaperRepo paperRepo;

    /**
     * 删除试评任务，保留标准卷
     *
     * @param workId
     * @param subject
     */
    @Transactional
    public void finishTrial(Long workId, Subject subject) {
        Work work = workRepo.findOne(workId);
        //1.更新科目为处始状态并设置test为false
        AtomicBoolean deleteStu = new AtomicBoolean(false);
        work.getSubjects().forEach(o -> {
            if (o.getId().toUpperCase().contains(subject.toString().toUpperCase())) {
                o.setTest(TrialEnum.DEFAULT.getId());
                o.setStage(MarkStage.INIT);
                o.setTotalScore(0);
                o.setSampleCount(0);
            }
            if (o.getTest() == TrialEnum.DEFAULT.getId()) {
                deleteStu.set(true);
            } else {
                deleteStu.set(false);
            }
        });
        markSubjectRepo.save(work.getSubjects());

        //2.删除该科目下所有任务数据
        markTaskRepo.deleteByWorkIdAndSubject(workId, subject);
        //3.删除所有学生数据(只有当前work下所有科目都设置为false则删除)
        if (deleteStu.get()) {
            studentRepo.deleteByWorkId(workId);
        }
        //4.更新该科目下的试卷信息,可暂且不更新
//        List<Paper> paperList = paperRepo.findByWorkIdAndSubjectAndTest(workId, subject, true);
//        paperList.forEach(o -> {
//            o.setLevel(null);//更新档位
//            o.setScore(null);//更新分数
//        });
//        paperRepo.save(paperList);
        //5.删除学生的试卷信息(服务器图片)
    }
}
